<?php
/*
  Plugin Name: All In One WP Security Reset Settings
  Plugin URI: https://www.tipsandtricks-hq.com/all-in-one-wp-security-reset-settings-plugin
  Description: This plugin will reset the settings of the All In One WP Security and Firewall Plugin. Useful for cases when you may be locked out.
  Author: Peter Petreski
  Version: 1.2
  Author URI: http://www.site-scanners.com/
 */

if (!class_exists('AIOWPSResetSettings')) {

    class AIOWPSResetSettings {

        function __construct() {
            $this->define_constants();
            $this->loader_operations();

            add_action('admin_menu', array($this, 'add_admin_menus'));
            add_filter('plugin_action_links', array($this, 'aiowps_reset_settings_add_settings_link'), 10, 2);
        }

        function define_constants() {
            global $wpdb;
            define('AIOWPSRS_PLUGIN_DB_VERSION', '1.0');
            define('AIOWPSRS_PLUGIN_PATH', dirname(__FILE__));
            define('AIOWPSRS_PLUGIN_URL', plugins_url('', __FILE__));
        }

        function loader_operations() {
            add_action('plugins_loaded', array($this, 'aiowps_reset_execute_plugins_loaded_operations'));
        }

        function aiowps_reset_execute_plugins_loaded_operations() {
            //NOP
        }

        function aiowps_reset_settings_add_settings_link($links, $file) {
            if ($file == plugin_basename(__FILE__)) {
                $settings_link = '<a href="options-general.php?page=aiowps_reset_settings_plugin_options">Settings</a>';
                array_unshift($links, $settings_link);
            }
            return $links;
        }

        function add_admin_menus() {
            //$aiowps_reset_page = add_options_page('AIOWPS Reset', 'AIOWPS Reset', 'manage_options', $this->aiowps_reset_options_key, array(&$this, 'aiowps_reset_settings_plugin_option_page'));
            if (function_exists('add_options_page')) {
                add_options_page('AIOWPS Reset', 'AIOWPS Reset', 'manage_options', __FILE__, array($this, 'aiowps_reset_settings_plugin_option_page'));
            }
        }

        function aiowps_reset_settings_plugin_option_page() {
            ?>
            <div class="wrap">

                <div id="poststuff"><div id="post-body">

                        <style>
                            .aio_orange_box {
                                background-color: #ffb900;
                                border-color: #d64500;
                                border-radius: 3px;
                                border-style: solid;
                                border-width: 1px;
                                margin: 10px 0 15px;
                                padding: 0 1em;
                            }
                        </style>

                        <?php
                        if (isset($_POST['aiowps_reset_settings'])) {//Do form submission tasks
                            $errors = '';
                            $nonce = $_REQUEST['_wpnonce'];
                            if (!wp_verify_nonce($nonce, 'aiowps-reset-settings-nonce')) {
                                die("Nonce check failed for AIOWPS reset settings event!");
                            }

                            $delete_option_res = self::reset_aiowps_options();
                            $delete_htaccess = self::delete_aiowps_htaccess();
                            $truncate_db_tables = self::reset_aiowps_db_tables();

                            if ($delete_option_res === false) {
                                $errors .= '<p>' . __('Deletion of aio_wp_security_configs failed.', '') . '</p>';
                            }
                            if ($delete_htaccess === false) {
                                $errors .= '<p>' . __('Deletion of .htaccess directives failed.', '') . '</p>';
                            }
                            if ($errors) {
                                //didpsalay error message;
                                echo '<div class="error fade">' . $errors . '</div>';
                            } else {
                                //echo a success message
                                echo '<div id="message" class="updated fade"><p>AIOWPS settings have been successfully reset.</p></div>';
                            }
                        }
                        ?>
                        <form action="" method="POST">
                            <?php wp_nonce_field('aiowps-reset-settings-nonce'); ?>            

                            <div class="postbox">
                                <h3 class="hndle"><label for="title"><?php _e('Reset Settings of All in One WP Security Plugin', 'aiowpsecurity'); ?></label></h3>
                                <div class="inside">
                                    <div class="aio_orange_box">
                                        <?php
                                        echo '<p>This plugin will delete all of your settings which are related to the All In One WP Security & Firewall Plugin.</p>';
                                        echo '<p>This plugin will reset/empty all the database tables of the security plugin also.</p>';
                                        echo '<p>Use this plugin if you were locked out by the All In One WP Security & Firewall Plugin and/or you are having issues logging in when that plugin is activated.</p>';
                                        echo '<p>In addition to the settings it will also delete any directives which were added to the .htaccess file by the All In One WP Security & Firewall Plugin.</p>';
                                        echo '<p><strong>NOTE: </strong>After deleting the settings you will need to re-configure the AIOWPS plugin.</p>';
                                        ?>
                                    </div>
                                    <input type="submit" name="aiowps_reset_settings" value="<?php _e('Reset Settings', '') ?>" class="button-primary" />
                                </div></div>
                        </form>
                    </div></div>

            </div>
            <?php
        }

        static function reset_aiowps_options() {
            $result = delete_option('aio_wp_security_configs');
            return $result;
        }

        static function delete_aiowps_htaccess($section = 'All In One WP Security') {
            $htaccess = ABSPATH . '.htaccess';

            @ini_set('auto_detect_line_endings', true);
            if (!file_exists($htaccess)) {
                return false;
            }
            $ht_contents = explode(PHP_EOL, implode('', file($htaccess))); //parse each line of file into array
            if ($ht_contents) { //as long as there are lines in the file
                $state = true;
                if (!$f = @fopen($htaccess, 'w+')) {
                    @chmod($htaccess, 0644);
                    if (!$f = @fopen($htaccess, 'w+')) {
                        return false;
                    }
                }

                foreach ($ht_contents as $n => $markerline) { //for each line in the file
                    if (strpos($markerline, '# BEGIN ' . $section) !== false) { //if we're at the beginning of the section
                        $state = false;
                    }
                    if ($state == true) { //as long as we're not in the section keep writing
                        fwrite($f, trim($markerline) . PHP_EOL);
                    }
                    if (strpos($markerline, '# END ' . $section) !== false) { //see if we're at the end of the section
                        $state = true;
                    }
                }
                @fclose($f);
                return true;
            }
            return true;
        }

        static function reset_aiowps_db_tables() {
            //Reset (TRUNCATE) all the db tables of the plugin.
            global $wpdb;

            $wpdb->query('TRUNCATE ' . $wpdb->prefix . 'aiowps_login_lockdown');
            $wpdb->query('TRUNCATE ' . $wpdb->prefix . 'aiowps_failed_logins');
            $wpdb->query('TRUNCATE ' . $wpdb->prefix . 'aiowps_login_activity');
            $wpdb->query('TRUNCATE ' . $wpdb->prefix . 'aiowps_global_meta');
            $wpdb->query('TRUNCATE ' . $wpdb->prefix . 'aiowps_events');
            $wpdb->query('TRUNCATE ' . $wpdb->prefix . 'aiowps_permanent_block');

            return true;
        }

    }

    //end class
}

$GLOBALS['aiowps_reset_settings_plugin'] = new AIOWPSResetSettings();
